@@ -10,5 +10,8 @@ $authenticate_text = array (
 'waitwhiletransfer'=>  'Sie werden weitergeleitet...',
 'clicknowait'      =>  'Weiter',
 
+// Added in 0.9.7
+'accountdisabled'  =>  'Ihr Benutzerkonto wurde deaktiviert. Wenden Sie sich an den Flyspray-Administrator.',
+
 );
 ?>
