@@ -1,4 +1,4 @@
-﻿<?php
+<?php
 
 global $chpass_text;
 $chpass_text = array (
