@@ -1,4 +1,4 @@
-﻿<?php
+<?php
 
 global $index_text;
 $index_text = array (
