@@ -10,6 +10,8 @@ $loginbox_text = array (
 // Added in 0.9.6
 'rememberme'    =>  'Bei jedem Besuch automatisch einloggen', 
 
+// Added in 0.9.7
+'lostpassword'  =>  'Passwort vergessen?',
 
 );
 ?>
