@@ -1,4 +1,4 @@
-﻿<?php
+<?php
 
 global $newuser_text;
 $newuser_text = array (
@@ -15,8 +15,10 @@ $newuser_text = array (
 'none'            =>  'Keine',
 'email'           =>  'E-Mail',
 'jabber'          =>  'Jabber',
-'group'           =>  'Gruppe',
 'registeraccount' =>  'Benutzer registrieren',
 
+// New in 0.9.7
+'globalgroup'     =>  'Globale Gruppe',
+
 );
 ?>
