@@ -10,5 +10,8 @@ $loginbox_text = array (
 // Added in 0.9.6
 'rememberme'				=>	'Ricordami', 
 
+// Added in 0.9.7
+'lostpassword'				=>	'Hai perso la password?',
+
 );
 ?>
