@@ -10,5 +10,8 @@ $authenticate_text = array (
 'waitwhiletransfer'	=>	'Wacht even alstublieft terwijl u doorverwezen wordt...',
 'clicknowait'		=>	'Klik hier als u niet wenst te wachten',
 
+// Added in 0.9.7
+'accountdisabled'       =>      'Uw account is uitgeschakeld.  Neem contact op met een beheerder.',
+
 );
 ?>
