@@ -12,7 +12,7 @@ $index_text = array (
 
 'search'	=>	'Szukaj',
 'alltasktypes'	=>	'Dowolny typ',
-'allseverities'	=>	'Dowolna dotkliwość',
+'allseverities'	=>	'Dowolna ważność',
 'alldevelopers'	=>	'Wszyscy programiści',
 'notyetassigned'=>	'Zadania nieprzydzielone',
 'allcategories'	=>	'Dowolna kategoria',
@@ -21,8 +21,8 @@ $index_text = array (
 'sortthiscolumn'=>	'Sortuj według kolumny',
 'id'		=>	'ID',
 'tasktype'	=>	'Typ zgłoszenia',
-'severity'	=>	'Dotkliwość',
-'summary'	=>	'W skrócie',
+'severity'	=>	'Ważność',
+'summary'	=>	'Skrócony opis',
 'dateopened'	=>	'Data otwarcia',
 'status'	=>	'Status',
 'progress'	=>	'Postęp',
