@@ -7,13 +7,16 @@
 // tomash@fidonet.org.pl, tomash@4net.pl
 
 $loginbox_text = array (
-'username'	=>	'Nazwa',
+'username'	=>	'Nazwa użytkownika',
 'password'	=>	'Hasło',
 'login'		=>	'Zaloguj!',
 
 // Added in 0.9.6
 'rememberme'	=>	'Zapamiętaj dane', 
 
+// Added in 0.9.7
+'lostpassword'				=>	'Zapomniane hasło?',
+
 );
 // vim:fenc=utf-8:enc=utf-8
 ?>
