@@ -1,16 +1,30 @@
 <?php
-// set a whole bunch of DEFAULT variables if they're not already set
-//  this is a whole convoluted bunch of crap, but it works.
+
+/*
+   This script sets up and shows the front page with
+   the list of all available tasks that the user is
+   allowed to view.
+*/
+
+// First, set a whole bunch of DEFAULT variables if they're not
+// already set. This is a whole convoluted bunch of crap, but it works.
 
 get_language_pack($lang, 'index');
 
-$orderby = array($_GET['order'], $_GET['order2']);
+$orderby = array($_GET['order']);
+
+if ($_GET['order2'] != '') {
+  $orderby[] = $_GET['order2'];
+} else {
+  $orderby[] = 'pri';
+};
 
 foreach ( $orderby as $key => $val ) {
   switch ($orderby[$key]) {
     case "id": $orderby[$key] = 'task_id';
     break;
-    case "proj": $orderby[$key] = 'attached_to_project';
+    //case "proj": $orderby[$key] = 'attached_to_project';
+    case "proj": $orderby[$key] = 'project_title';
     break;
     case "type": $orderby[$key] = 'tasktype_name';
     break;
@@ -18,11 +32,12 @@ foreach ( $orderby as $key => $val ) {
     break;
     case "sev": $orderby[$key] = 'task_severity';
     break;
-    case "cat": $orderby[$key] = 'product_category';
+    //case "cat": $orderby[$key] = 'product_category';
+    case "cat": $orderby[$key] = 'lc.category_name';
     break;
     case "status": $orderby[$key] = 'item_status';
     break;
-    case "due": $orderby[$key] = 't.closedby_version';
+    case "due": $orderby[$key] = 'lvc.list_position';
     break;
     case "prog": $orderby[$key] = 'percent_complete';
     break;
@@ -30,11 +45,13 @@ foreach ( $orderby as $key => $val ) {
     break;
     case "pri": $orderby[$key] = 'task_priority';
     break;
-    case "openedby": $orderby[$key] = 't.opened_by';
+    //case "openedby": $orderby[$key] = 't.opened_by';
+    case "openedby": $orderby[$key] = 'uo.real_name';
     break;
     case "reportedin": $orderby[$key] = 't.product_version';
     break;
-    case "assignedto": $orderby[$key] = 't.assigned_to';
+    //case "assignedto": $orderby[$key] = 't.assigned_to';
+    case "assignedto": $orderby[$key] = 'u.real_name';
     break;
     default: $orderby[$key] = 'task_severity';
     break;
@@ -53,7 +70,7 @@ foreach ( $sort as $key => $val ) {
   };
 };
 
-$sortorder = "{$orderby[0]} {$sort[0]}, {$orderby[1]} {$sort[1]}"; 
+$sortorder = "{$orderby[0]} {$sort[0]}, {$orderby[1]} {$sort[1]}, t.task_id ASC"; 
 
 // Check that what was submitted is a numerical value; most of them should be
 
@@ -79,8 +96,37 @@ $where = array();
 $where[] = 'project_is_active = ?';
 $sql_params[] = '1';
 
-// Set the default queries
-if ($_GET['project'] != '0') {
+
+// Set the default projects to show tasks from
+if ($_GET['project'] == '0') {
+
+  // First, check global permissions
+  if ($global_permissions['view_tasks'] == '0') {
+
+    // Find out which projects we are actually allow to view
+    $check_projects = $fs->dbQuery("SELECT p.project_id
+                                    FROM flyspray_projects p
+                                    LEFT JOIN flyspray_groups g ON p.project_id = g.belongs_to_project
+                                    LEFT JOIN flyspray_users_in_groups uig ON g.group_id = uig.group_id
+                                    WHERE uig.user_id = ? AND g.view_tasks = ?",
+                                    array($current_user['user_id'], '1')
+                                  );
+
+    $temp_where = "(attached_to_project = ?";
+    $sql_params[] = '0';
+
+    // Cycle through the projects, selecting the ones that the user is allowed to view
+    while ($this_project = $fs->dbFetchArray($check_projects)) {
+      $temp_where = $temp_where . " OR attached_to_project = ?";
+      $sql_params[] = $this_project['project_id'];
+    };
+    
+    $where[] = $temp_where . ")";
+
+  };
+
+// If we're not selecting all projects
+} else {
   $where[]	= "attached_to_project = ?";
   $sql_params[] = $project_id;
 };
@@ -89,14 +135,14 @@ if ($_GET['project'] != '0') {
 $dev = $_GET['dev'];
 
 if ($_GET['tasks'] == 'assigned') {
-    $dev = $_SESSION['userid'];
+    $dev = $current_user['user_id'];
 } elseif ($_GET['tasks'] == 'reported') {
     $where[] = 'opened_by = ?';
-    $sql_params[] = $_SESSION['userid'];
+    $sql_params[] = $current_user['user_id'];
 };
 
 
-// developer whos bugs to show
+// developer whose bugs to show
 if (is_numeric($dev)) {
   $where[] = "assigned_to = ?";
   $sql_params[] = $dev;
@@ -140,7 +186,7 @@ if ($_GET['status'] == "all") {
   $where[] = "is_closed = ?";
   $sql_params[] = "1";
 } elseif (is_numeric($_GET['status'])) {
-  $where[]	= "item_status = ?";
+  $where[]	= "item_status = ? AND is_closed <> '1'";
   $sql_params[] = $_GET['status'];
 } else {
   $where[] = "is_closed != ?";
@@ -164,6 +210,17 @@ if ($_GET['string']) {
   $sql_params[] = "%$string%";
 };
 
+// Do this to hide private tasks from the list
+if ($permissions['manage_project'] == '1') {
+	// Don't add any parameters
+} elseif ($permissions['manage_project'] != '1'
+     && isset($_COOKIE['flyspray_userid'])) {
+  $where[] = "(t.mark_private <> '1' OR t.assigned_to = ?)";
+  $sql_params[] = $current_user['user_id'];
+} elseif (!isset($_COOKIE['user_id'])) {
+  $where[] = "t.mark_private <> '1'";
+};
+
 if ($_GET['project'] == '0') {
     $get = "&amp;project=0";
 } else {
@@ -178,6 +235,16 @@ $extraurl .= "&amp;order2={$_GET['order2']}&amp;sort2={$_GET['sort2']}";
 
 ?>
 
+<?php
+// Check that the requested project is active
+$getproject = $fs->dbFetchArray($fs->dbQuery('SELECT * FROM flyspray_projects WHERE project_id = ?', array($project_id)));
+
+if ($getproject['project_is_active'] == 1
+    && ($project_prefs['others_view'] == '1' OR $permissions['view_tasks'] == '1')
+    ) {
+?>
+
+
 <!-- Query line -->
 <map id="projectsearchform" name="projectsearchform">
 <form action="index.php" method="get">
@@ -241,7 +308,7 @@ $extraurl .= "&amp;order2={$_GET['order2']}&amp;sort2={$_GET['sort2']}";
       <option value=""><?php echo $index_text['alldevelopers'];?></option>
       <option value="notassigned" <?php if ($dev == "notassigned") { echo "SELECTED";};?>><?php echo $index_text['notyetassigned'];?></option>
       <?php
-      $fs->ListUsers($dev);
+      $fs->ListUsers($dev, $project_id);
       ?>
     </select>
 
@@ -313,9 +380,11 @@ $extraurl .= "&amp;order2={$_GET['order2']}&amp;sort2={$_GET['sort2']}";
  *
  * @param string $colname	The name of the column
  * @param string $orderkey	The actual key to use when ordering the list
+ * @param string $defaultsort The default sort order
  * @param string $image    An image to display instead of the column name
  */
-function list_heading($colname, $orderkey, $image = '')
+//function list_heading($colname, $orderkey, $image = '')
+function list_heading($colname, $orderkey, $defaultsort = 'desc', $image = '')
 {
   global $project_prefs;
   global $index_text;
@@ -343,6 +412,7 @@ function list_heading($colname, $orderkey, $image = '')
       }
       else
       {
+        $sort1 = $defaultsort;
         $order2 = $_GET['order'];
         $sort2 = $_GET['sort'];
       }
@@ -415,13 +485,6 @@ function list_cell($colname,$cellvalue,$nowrap=0,$url=0)
 
 ?>
 
-
-<?php
-// Check that the requested project is active
-$getproject = $fs->dbFetchArray($fs->dbQuery('SELECT * FROM flyspray_projects WHERE project_id = ?', array($project_id)));
-if ($getproject['project_is_active'] == 1) {
-?>
-
 <!--  Summary headings, followed by the query results -->
 <table id="tasklist">
 <thead>
@@ -429,21 +492,28 @@ if ($getproject['project_is_active'] == 1) {
 
   <?php
   list_heading('id','id');
-  list_heading('project','proj');
-  list_heading('tasktype','type');  
-  list_heading('category','cat');
+  //list_heading('project','proj');
+  //list_heading('tasktype','type');  
+  //list_heading('category','cat');
+  list_heading('project','proj','asc');
+  list_heading('tasktype','type','asc');
+  list_heading('category','cat','asc');
   list_heading('severity','sev');
   list_heading('priority','pri');
   list_heading('summary','');
   list_heading('dateopened','date');
   list_heading('status','status');
-  list_heading('openedby','openedby');
-  list_heading('assignedto','assignedto');
+  //list_heading('openedby','openedby');
+  //list_heading('assignedto','assignedto');
+  list_heading('openedby','openedby','asc');
+  list_heading('assignedto','assignedto','asc');
   list_heading('lastedit', 'lastedit');
   list_heading('reportedin','reportedin');
   list_heading('dueversion','due');
-  list_heading('comments','', "themes/{$project_prefs['theme_style']}/comment.png");
-  list_heading('attachments','', "themes/{$project_prefs['theme_style']}/attachment.png");
+  //list_heading('comments','', "themes/{$project_prefs['theme_style']}/comment.png");
+  //list_heading('attachments','', "themes/{$project_prefs['theme_style']}/attachment.png");
+  list_heading('comments','','', "themes/{$project_prefs['theme_style']}/comment.png");
+  list_heading('attachments','','', "themes/{$project_prefs['theme_style']}/attachment.png");
   list_heading('progress','prog');
   ?>
 
@@ -459,7 +529,7 @@ if ($_GET['tasks'] == 'watched') {
     //join the notification table to get watched tasks
     $from .= ' RIGHT JOIN flyspray_notifications fsn ON t.task_id = fsn.task_id';
     $where[] = 'fsn.user_id = ?';
-    $sql_params[] = $_SESSION['userid'];
+    $sql_params[] = $current_user['user_id'];
 };
 
 // This SQL courtesy of Lance Conry http://www.rhinosw.com/
@@ -588,6 +658,7 @@ ORDER BY
 </table>
 
 <?php
-// End of checking if the reqeusted project is active
+// End of checking if the reqeusted project is active,
+// and that the user has permission to view it
 };
 ?>
